fn bin_ms(ts: Expr) -> ExprExpand description
date_bin(60s, ts) cast to millisecond precision, so the output schema is
deterministic regardless of the source column’s precision (trace tables are
nanosecond, metric tables millisecond).
fn bin_ms(ts: Expr) -> Exprdate_bin(60s, ts) cast to millisecond precision, so the output schema is
deterministic regardless of the source column’s precision (trace tables are
nanosecond, metric tables millisecond).